@@ -221,10 +221,6 @@ class IMAPServer(object):
         return retval
 
     def __xoauth2handler(self, response):
-        if self.oauth2_refresh_token is None \
-                and self.oauth2_access_token is None:
-            return None
-
         if self.oauth2_access_token is None:
             if self.oauth2_request_url is None:
                 raise OfflineImapError("No remote oauth2_request_url for "
@@ -353,6 +349,10 @@ class IMAPServer(object):
         return True
 
     def __authn_xoauth2(self, imapobj):
+        if self.oauth2_refresh_token is None \
+                and self.oauth2_access_token is None:
+            return False
+
         imapobj.authenticate('XOAUTH2', self.__xoauth2handler)
         return True
 
@@ -527,6 +527,8 @@ class IMAPServer(object):
                 elif self.usessl:
                     self.ui.connecting(
                         self.repos.getname(), self.hostname, self.port)
+                    self.ui.debug('imap', "%s: level '%s', version '%s'"%
+                        (self.repos.getname(), self.tlslevel, self.sslversion))
                     imapobj = imaplibutil.WrappedIMAP4_SSL(
                         host=self.hostname,
                         port=self.port,
